@@ -4,8 +4,12 @@
 # Author            : Chi Han, Jiayuan Mao
 # Email             : haanchi@gmail.com, maojiayuan@gmail.com
 # Date              : 09.08.2019
-# Last Modified Date: 09.08.2019
-# Last Modified By  : Chi Han, Jiayuan Mao
+# Last Modified Date: 12.18.2021
+# Last Modified By  : Jimmy Yao
 #
 # This file is part of the VCML codebase
 # Distributed under MIT license
+
+from .file_utils import load, make_dir, dump 
+
+__all__ = ['file_utils', 'basis_utils', 'code_utils', 'load', 'make_dir', 'dump']
