@@ -18,7 +18,15 @@ import numpy as np
 
 
 def import_plt(style="seaborn-darkgrid", backend="Qt5Agg", fontsize=10, usetex=True):
-    matplotlib.use(backend)
+    # robust backend
+    try: 
+        matplotlib.use(backend)
+    except: 
+        try: 
+            matplotlib.use('TKAgg')
+        except: 
+            matplotlib.use('Agg')
+        
     import matplotlib.pyplot as plt
 
     plt.style.use(style)
@@ -97,7 +105,7 @@ def get_axes(num, plt):
     nrows = int(np.sqrt(num))
     ncols = num // nrows + 1
 
-    fig, ax = plt.subplots(nrows=nrows, ncols=ncols, figsize=(ncols * 4, nrows * 4))
+    fig, ax = plt.subplots(nrows=nrows, ncols=ncols, figsize=(ncols * 6.4, nrows * 4.8))
     ax_array = ax.flatten()
     return fig, ax_array
 
@@ -114,4 +122,4 @@ def plt_end(filename=None, show=True, tight=True):
     if show:
         plt.show()
 
-# plt = import_plt()
+plt = import_plt()
